## CONTRIBUTING

#### If you would like to contribute, please read this doc

### Guidelines:

1. Please try to follow other files created by me carefully
2. Any pull request is appreciated, **even a single typo or indent!**
3. Anyone who made a good pr will be added to contributors so you can commit directly
4. Good luck and have fun!

### Notes

* There are some other documents for contributing, so go and see them!
